@@ -71,35 +71,36 @@
 #'    comparative study of word co-occurrence for term clustering in language 
 #'   model-based sentence retrieval.}" \emph{Human Language Technologies: The 
 #'   2010 Annual Conference of the North American Chapter of the ACL}, Los 
-#'   Angeles, California, June 2010, pp. 325-328.
+#'   Angeles, California, June 2010, 325-328.
 #'   
-#'   Jurafsky, Daniel and James H. Martin (2018). "Chapter 6, Vector Semantics."
-#'   from \emph{Speech and Language Processing}.  Draft of September 23, 2018,
-#'   from \url{https://web.stanford.edu/~jurafsky/slp3/}.
+#'   Jurafsky, D. & Martin, J.H. (2018).
+#'   From \emph{Speech and Language Processing: An Introduction to Natural Language Processing, 
+#'   Computational Linguistics, and Speech Recognition}. Draft of September 23, 2018 
+#'   (Chapter 6, Vector Semantics). Available at \url{https://web.stanford.edu/~jurafsky/slp3/}.
 #'   
-#'   Church, K. W. & P. Hanks (1990) 
-#'   "\href{http://dl.acm.org/citation.cfm?id=89095}{Word association norms,
-#'   mutual information, and lexicography}" \emph{Computational Linguistics},
-#'   16(1):22–29.
+#'   Church, K. W. & P. Hanks (1990) .
+#'  \href{http://dl.acm.org/citation.cfm?id=89095}{Word association norms,
+#'   mutual information, and lexicography}. \emph{Computational Linguistics},
+#'   16(1), 22–29.
 #' @examples
 #' # see http://bit.ly/29b2zOA
-#' txt <- "A D A C E A D F E B A C E D"
-#' fcm(txt, context = "window", window = 2)
-#' fcm(txt, context = "window", count = "weighted", window = 3)
-#' fcm(txt, context = "window", count = "weighted", window = 3, 
+#' txt1 <- "A D A C E A D F E B A C E D"
+#' fcm(txt1, context = "window", window = 2)
+#' fcm(txt1, context = "window", count = "weighted", window = 3)
+#' fcm(txt1, context = "window", count = "weighted", window = 3, 
 #'              weights = c(3, 2, 1), ordered = TRUE, tri = FALSE)
 #' 
 #' # with multiple documents
-#' txts <- c("a a a b b c", "a a c e", "a c e f g")
-#' fcm(txts, context = "document", count = "frequency")
-#' fcm(txts, context = "document", count = "boolean")
-#' fcm(txts, context = "window", window = 2)
+#' txt2 <- c("a a a b b c", "a a c e", "a c e f g")
+#' fcm(txt2, context = "document", count = "frequency")
+#' fcm(txt2, context = "document", count = "boolean")
+#' fcm(txt2, context = "window", window = 2)
 #' 
 #' 
 #' # from tokens
-#' txt <- c("The quick brown fox jumped over the lazy dog.",
+#' txt3 <- c("The quick brown fox jumped over the lazy dog.",
 #'          "The dog jumped and ate the fox.")
-#' toks <- tokens(char_tolower(txt), remove_punct = TRUE)
+#' toks <- tokens(char_tolower(txt3), remove_punct = TRUE)
 #' fcm(toks, context = "document")
 #' fcm(toks, context = "window", window = 3)
 fcm <- function(x, context = c("document", "window"), 
@@ -188,9 +189,8 @@ fcm.dfm <- function(x, context = c("document", "window"),
     result <- new("fcm", as(result, "dgCMatrix"), count = count,
                   context = context, window = window, margin = margin,
                   weights = weights, tri = tri)
-    # set the names 
-    names(result@Dimnames) <- c("features", "features")
-    result
+    set_fcm_dimnames(result) <- list(rownames(result), colnames(result))
+    return(result)
 }
 
     
@@ -225,11 +225,11 @@ fcm.tokens <- function(x, context = c("document", "window"),
             }
         }
         if (!is.tokens(x)) x <- as.tokens(x)
-        types <- types(x)
+        type <- types(x)
         n <- sum(lengths(x)) * window * 2
-        result <- as(qatd_cpp_fcm(x, length(types), count, window, 
+        result <- as(qatd_cpp_fcm(x, length(type), count, window, 
                                   weights, ordered, tri, n), "dgCMatrix")
-        dimnames(result) <- list(features = types, features = types)
+        set_fcm_dimnames(result) <- list(type, type)
     }
 
     # discard the lower diagonal if tri == TRUE
@@ -239,9 +239,7 @@ fcm.tokens <- function(x, context = c("document", "window"),
     result <- new("fcm", as(result, "dgCMatrix"), count = count,
                   context = context, window = window, margin = colSums(dfm(x)),
                   weights = weights, tri = tri)
-    # set the names 
-    names(result@Dimnames) <- c("features", "features")
-    result
+    return(result)
 }     
 
 #' @rdname print.dfm
